# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectMemberArgs', 'ProjectMember']

@pulumi.input_type
class ProjectMemberArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[builtins.int],
                 user_id: pulumi.Input[builtins.str],
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]] = None):
        """
        The set of arguments for constructing a ProjectMember resource.
        :param pulumi.Input[builtins.int] project_id: Project ID
        :param pulumi.Input[builtins.str] user_id: The user ID of the member.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]] roles: List of roles owned by members. See `roles` below.
        """
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "user_id", user_id)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.int]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[builtins.str]:
        """
        The user ID of the member.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]:
        """
        List of roles owned by members. See `roles` below.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]):
        pulumi.set(self, "roles", value)


@pulumi.input_type
class _ProjectMemberState:
    def __init__(__self__, *,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectMember resources.
        :param pulumi.Input[builtins.int] project_id: Project ID
        :param pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]] roles: List of roles owned by members. See `roles` below.
        :param pulumi.Input[builtins.str] status: The status of the user in project
        :param pulumi.Input[builtins.str] user_id: The user ID of the member.
        """
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]:
        """
        List of roles owned by members. See `roles` below.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the user in project
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The user ID of the member.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("alicloud:dataworks/projectMember:ProjectMember")
class ProjectMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectMemberRoleArgs', 'ProjectMemberRoleArgsDict']]]]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Data Works Project Member resource.

        For information about Data Works Project Member and how to use it, see [What is Project Member](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createprojectmember).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        admin_code = config.get("adminCode")
        if admin_code is None:
            admin_code = "role_project_admin"
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default_kc_tr_b2 = alicloud.ram.User("defaultKCTrB2",
            display_name=f"{name}{randint['id']}",
            name=f"{name}{randint['id']}")
        default = alicloud.resourcemanager.get_resource_groups()
        default_qe_rfv_u = alicloud.dataworks.Project("defaultQeRfvU",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        default_project_member = alicloud.dataworks.ProjectMember("default",
            user_id=default_kc_tr_b2.id,
            project_id=default_qe_rfv_u.id,
            roles=[{
                "code": admin_code,
            }])
        ```

        ## Import

        Data Works Project Member can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/projectMember:ProjectMember example <project_id>:<user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] project_id: Project ID
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectMemberRoleArgs', 'ProjectMemberRoleArgsDict']]]] roles: List of roles owned by members. See `roles` below.
        :param pulumi.Input[builtins.str] user_id: The user ID of the member.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Project Member resource.

        For information about Data Works Project Member and how to use it, see [What is Project Member](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createprojectmember).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        admin_code = config.get("adminCode")
        if admin_code is None:
            admin_code = "role_project_admin"
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default_kc_tr_b2 = alicloud.ram.User("defaultKCTrB2",
            display_name=f"{name}{randint['id']}",
            name=f"{name}{randint['id']}")
        default = alicloud.resourcemanager.get_resource_groups()
        default_qe_rfv_u = alicloud.dataworks.Project("defaultQeRfvU",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        default_project_member = alicloud.dataworks.ProjectMember("default",
            user_id=default_kc_tr_b2.id,
            project_id=default_qe_rfv_u.id,
            roles=[{
                "code": admin_code,
            }])
        ```

        ## Import

        Data Works Project Member can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/projectMember:ProjectMember example <project_id>:<user_id>
        ```

        :param str resource_name: The name of the resource.
        :param ProjectMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectMemberRoleArgs', 'ProjectMemberRoleArgsDict']]]]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectMemberArgs.__new__(ProjectMemberArgs)

            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["roles"] = roles
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["status"] = None
        super(ProjectMember, __self__).__init__(
            'alicloud:dataworks/projectMember:ProjectMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project_id: Optional[pulumi.Input[builtins.int]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectMemberRoleArgs', 'ProjectMemberRoleArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ProjectMember':
        """
        Get an existing ProjectMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] project_id: Project ID
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectMemberRoleArgs', 'ProjectMemberRoleArgsDict']]]] roles: List of roles owned by members. See `roles` below.
        :param pulumi.Input[builtins.str] status: The status of the user in project
        :param pulumi.Input[builtins.str] user_id: The user ID of the member.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectMemberState.__new__(_ProjectMemberState)

        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["roles"] = roles
        __props__.__dict__["status"] = status
        __props__.__dict__["user_id"] = user_id
        return ProjectMember(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.int]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectMemberRole']]]:
        """
        List of roles owned by members. See `roles` below.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the user in project
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.str]:
        """
        The user ID of the member.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HttpsBasicConfigurationArgs', 'HttpsBasicConfiguration']

@pulumi.input_type
class HttpsBasicConfigurationArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 ciphersuite: Optional[pulumi.Input[builtins.str]] = None,
                 ciphersuite_group: Optional[pulumi.Input[builtins.str]] = None,
                 http2: Optional[pulumi.Input[builtins.str]] = None,
                 http3: Optional[pulumi.Input[builtins.str]] = None,
                 https: Optional[pulumi.Input[builtins.str]] = None,
                 ocsp_stapling: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 tls10: Optional[pulumi.Input[builtins.str]] = None,
                 tls11: Optional[pulumi.Input[builtins.str]] = None,
                 tls12: Optional[pulumi.Input[builtins.str]] = None,
                 tls13: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a HttpsBasicConfiguration resource.
        :param pulumi.Input[builtins.int] site_id: Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        :param pulumi.Input[builtins.str] ciphersuite: Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        :param pulumi.Input[builtins.str] ciphersuite_group: Cipher suite group. Default is all cipher suites. Possible values:
               - all: All cipher suites.
               - strict: Strong cipher suites.
               - custom: Custom cipher suites.
        :param pulumi.Input[builtins.str] http2: Indicates whether HTTP2 is enabled. Default is on. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] http3: Whether to enable HTTP3, which is enabled by default. The value can be:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] https: Whether to enable HTTPS. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] ocsp_stapling: Indicates whether OCSP is enabled. Default is off. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               -  Match all incoming requests: value set to true
               -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.str] tls10: Whether to enable TLS1.0. Default is disabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls11: Whether to enable TLS1.1. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls12: Whether to enable TLS1.2. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls13: Whether to enable TLS1.3. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        """
        pulumi.set(__self__, "site_id", site_id)
        if ciphersuite is not None:
            pulumi.set(__self__, "ciphersuite", ciphersuite)
        if ciphersuite_group is not None:
            pulumi.set(__self__, "ciphersuite_group", ciphersuite_group)
        if http2 is not None:
            pulumi.set(__self__, "http2", http2)
        if http3 is not None:
            pulumi.set(__self__, "http3", http3)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if ocsp_stapling is not None:
            pulumi.set(__self__, "ocsp_stapling", ocsp_stapling)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if tls10 is not None:
            pulumi.set(__self__, "tls10", tls10)
        if tls11 is not None:
            pulumi.set(__self__, "tls11", tls11)
        if tls12 is not None:
            pulumi.set(__self__, "tls12", tls12)
        if tls13 is not None:
            pulumi.set(__self__, "tls13", tls13)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def ciphersuite(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        """
        return pulumi.get(self, "ciphersuite")

    @ciphersuite.setter
    def ciphersuite(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ciphersuite", value)

    @property
    @pulumi.getter(name="ciphersuiteGroup")
    def ciphersuite_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cipher suite group. Default is all cipher suites. Possible values:
        - all: All cipher suites.
        - strict: Strong cipher suites.
        - custom: Custom cipher suites.
        """
        return pulumi.get(self, "ciphersuite_group")

    @ciphersuite_group.setter
    def ciphersuite_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ciphersuite_group", value)

    @property
    @pulumi.getter
    def http2(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether HTTP2 is enabled. Default is on. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http2")

    @http2.setter
    def http2(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http2", value)

    @property
    @pulumi.getter
    def http3(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTP3, which is enabled by default. The value can be:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http3")

    @http3.setter
    def http3(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http3", value)

    @property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTPS. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https", value)

    @property
    @pulumi.getter(name="ocspStapling")
    def ocsp_stapling(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether OCSP is enabled. Default is off. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "ocsp_stapling")

    @ocsp_stapling.setter
    def ocsp_stapling(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ocsp_stapling", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        -  Match all incoming requests: value set to true
        -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter
    def tls10(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.0. Default is disabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls10")

    @tls10.setter
    def tls10(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls10", value)

    @property
    @pulumi.getter
    def tls11(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.1. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls11")

    @tls11.setter
    def tls11(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls11", value)

    @property
    @pulumi.getter
    def tls12(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.2. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls12")

    @tls12.setter
    def tls12(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls12", value)

    @property
    @pulumi.getter
    def tls13(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.3. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls13")

    @tls13.setter
    def tls13(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls13", value)


@pulumi.input_type
class _HttpsBasicConfigurationState:
    def __init__(__self__, *,
                 ciphersuite: Optional[pulumi.Input[builtins.str]] = None,
                 ciphersuite_group: Optional[pulumi.Input[builtins.str]] = None,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 http2: Optional[pulumi.Input[builtins.str]] = None,
                 http3: Optional[pulumi.Input[builtins.str]] = None,
                 https: Optional[pulumi.Input[builtins.str]] = None,
                 ocsp_stapling: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 tls10: Optional[pulumi.Input[builtins.str]] = None,
                 tls11: Optional[pulumi.Input[builtins.str]] = None,
                 tls12: Optional[pulumi.Input[builtins.str]] = None,
                 tls13: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering HttpsBasicConfiguration resources.
        :param pulumi.Input[builtins.str] ciphersuite: Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        :param pulumi.Input[builtins.str] ciphersuite_group: Cipher suite group. Default is all cipher suites. Possible values:
               - all: All cipher suites.
               - strict: Strong cipher suites.
               - custom: Custom cipher suites.
        :param pulumi.Input[builtins.int] config_id: ConfigId of the configuration, which can be obtained by calling the [ListHttpsBasicConfigurations](https://www.alibabacloud.com/help/en/doc-detail/2867470.html) interface.
        :param pulumi.Input[builtins.str] http2: Indicates whether HTTP2 is enabled. Default is on. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] http3: Whether to enable HTTP3, which is enabled by default. The value can be:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] https: Whether to enable HTTPS. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] ocsp_stapling: Indicates whether OCSP is enabled. Default is off. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               -  Match all incoming requests: value set to true
               -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        :param pulumi.Input[builtins.str] tls10: Whether to enable TLS1.0. Default is disabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls11: Whether to enable TLS1.1. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls12: Whether to enable TLS1.2. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls13: Whether to enable TLS1.3. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        """
        if ciphersuite is not None:
            pulumi.set(__self__, "ciphersuite", ciphersuite)
        if ciphersuite_group is not None:
            pulumi.set(__self__, "ciphersuite_group", ciphersuite_group)
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if http2 is not None:
            pulumi.set(__self__, "http2", http2)
        if http3 is not None:
            pulumi.set(__self__, "http3", http3)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if ocsp_stapling is not None:
            pulumi.set(__self__, "ocsp_stapling", ocsp_stapling)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if tls10 is not None:
            pulumi.set(__self__, "tls10", tls10)
        if tls11 is not None:
            pulumi.set(__self__, "tls11", tls11)
        if tls12 is not None:
            pulumi.set(__self__, "tls12", tls12)
        if tls13 is not None:
            pulumi.set(__self__, "tls13", tls13)

    @property
    @pulumi.getter
    def ciphersuite(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        """
        return pulumi.get(self, "ciphersuite")

    @ciphersuite.setter
    def ciphersuite(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ciphersuite", value)

    @property
    @pulumi.getter(name="ciphersuiteGroup")
    def ciphersuite_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cipher suite group. Default is all cipher suites. Possible values:
        - all: All cipher suites.
        - strict: Strong cipher suites.
        - custom: Custom cipher suites.
        """
        return pulumi.get(self, "ciphersuite_group")

    @ciphersuite_group.setter
    def ciphersuite_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ciphersuite_group", value)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ConfigId of the configuration, which can be obtained by calling the [ListHttpsBasicConfigurations](https://www.alibabacloud.com/help/en/doc-detail/2867470.html) interface.
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter
    def http2(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether HTTP2 is enabled. Default is on. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http2")

    @http2.setter
    def http2(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http2", value)

    @property
    @pulumi.getter
    def http3(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTP3, which is enabled by default. The value can be:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http3")

    @http3.setter
    def http3(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http3", value)

    @property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTPS. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https", value)

    @property
    @pulumi.getter(name="ocspStapling")
    def ocsp_stapling(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether OCSP is enabled. Default is off. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "ocsp_stapling")

    @ocsp_stapling.setter
    def ocsp_stapling(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ocsp_stapling", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        -  Match all incoming requests: value set to true
        -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def tls10(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.0. Default is disabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls10")

    @tls10.setter
    def tls10(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls10", value)

    @property
    @pulumi.getter
    def tls11(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.1. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls11")

    @tls11.setter
    def tls11(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls11", value)

    @property
    @pulumi.getter
    def tls12(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.2. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls12")

    @tls12.setter
    def tls12(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls12", value)

    @property
    @pulumi.getter
    def tls13(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable TLS1.3. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls13")

    @tls13.setter
    def tls13(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls13", value)


@pulumi.type_token("alicloud:esa/httpsBasicConfiguration:HttpsBasicConfiguration")
class HttpsBasicConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ciphersuite: Optional[pulumi.Input[builtins.str]] = None,
                 ciphersuite_group: Optional[pulumi.Input[builtins.str]] = None,
                 http2: Optional[pulumi.Input[builtins.str]] = None,
                 http3: Optional[pulumi.Input[builtins.str]] = None,
                 https: Optional[pulumi.Input[builtins.str]] = None,
                 ocsp_stapling: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 tls10: Optional[pulumi.Input[builtins.str]] = None,
                 tls11: Optional[pulumi.Input[builtins.str]] = None,
                 tls12: Optional[pulumi.Input[builtins.str]] = None,
                 tls13: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Https Basic Configuration resource.

        For information about ESA Https Basic Configuration and how to use it, see [What is Https Basic Configuration](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateHttpsBasicConfiguration).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        example = alicloud.esa.RatePlanInstance("example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_http_basic_configuration_set_example = alicloud.esa.Site("resource_HttpBasicConfiguration_set_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=example.id,
            coverage="overseas",
            access_type="NS")
        default_https_basic_configuration = alicloud.esa.HttpsBasicConfiguration("default",
            https="on",
            rule="true",
            rule_name="example2",
            site_id=resource_http_basic_configuration_set_example.id,
            rule_enable="on")
        ```

        ## Import

        ESA Https Basic Configuration can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpsBasicConfiguration:HttpsBasicConfiguration example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ciphersuite: Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        :param pulumi.Input[builtins.str] ciphersuite_group: Cipher suite group. Default is all cipher suites. Possible values:
               - all: All cipher suites.
               - strict: Strong cipher suites.
               - custom: Custom cipher suites.
        :param pulumi.Input[builtins.str] http2: Indicates whether HTTP2 is enabled. Default is on. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] http3: Whether to enable HTTP3, which is enabled by default. The value can be:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] https: Whether to enable HTTPS. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] ocsp_stapling: Indicates whether OCSP is enabled. Default is off. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               -  Match all incoming requests: value set to true
               -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        :param pulumi.Input[builtins.str] tls10: Whether to enable TLS1.0. Default is disabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls11: Whether to enable TLS1.1. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls12: Whether to enable TLS1.2. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls13: Whether to enable TLS1.3. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpsBasicConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Https Basic Configuration resource.

        For information about ESA Https Basic Configuration and how to use it, see [What is Https Basic Configuration](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateHttpsBasicConfiguration).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        example = alicloud.esa.RatePlanInstance("example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_http_basic_configuration_set_example = alicloud.esa.Site("resource_HttpBasicConfiguration_set_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=example.id,
            coverage="overseas",
            access_type="NS")
        default_https_basic_configuration = alicloud.esa.HttpsBasicConfiguration("default",
            https="on",
            rule="true",
            rule_name="example2",
            site_id=resource_http_basic_configuration_set_example.id,
            rule_enable="on")
        ```

        ## Import

        ESA Https Basic Configuration can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpsBasicConfiguration:HttpsBasicConfiguration example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param HttpsBasicConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpsBasicConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ciphersuite: Optional[pulumi.Input[builtins.str]] = None,
                 ciphersuite_group: Optional[pulumi.Input[builtins.str]] = None,
                 http2: Optional[pulumi.Input[builtins.str]] = None,
                 http3: Optional[pulumi.Input[builtins.str]] = None,
                 https: Optional[pulumi.Input[builtins.str]] = None,
                 ocsp_stapling: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 tls10: Optional[pulumi.Input[builtins.str]] = None,
                 tls11: Optional[pulumi.Input[builtins.str]] = None,
                 tls12: Optional[pulumi.Input[builtins.str]] = None,
                 tls13: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpsBasicConfigurationArgs.__new__(HttpsBasicConfigurationArgs)

            __props__.__dict__["ciphersuite"] = ciphersuite
            __props__.__dict__["ciphersuite_group"] = ciphersuite_group
            __props__.__dict__["http2"] = http2
            __props__.__dict__["http3"] = http3
            __props__.__dict__["https"] = https
            __props__.__dict__["ocsp_stapling"] = ocsp_stapling
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["tls10"] = tls10
            __props__.__dict__["tls11"] = tls11
            __props__.__dict__["tls12"] = tls12
            __props__.__dict__["tls13"] = tls13
            __props__.__dict__["config_id"] = None
        super(HttpsBasicConfiguration, __self__).__init__(
            'alicloud:esa/httpsBasicConfiguration:HttpsBasicConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ciphersuite: Optional[pulumi.Input[builtins.str]] = None,
            ciphersuite_group: Optional[pulumi.Input[builtins.str]] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            http2: Optional[pulumi.Input[builtins.str]] = None,
            http3: Optional[pulumi.Input[builtins.str]] = None,
            https: Optional[pulumi.Input[builtins.str]] = None,
            ocsp_stapling: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            tls10: Optional[pulumi.Input[builtins.str]] = None,
            tls11: Optional[pulumi.Input[builtins.str]] = None,
            tls12: Optional[pulumi.Input[builtins.str]] = None,
            tls13: Optional[pulumi.Input[builtins.str]] = None) -> 'HttpsBasicConfiguration':
        """
        Get an existing HttpsBasicConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ciphersuite: Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        :param pulumi.Input[builtins.str] ciphersuite_group: Cipher suite group. Default is all cipher suites. Possible values:
               - all: All cipher suites.
               - strict: Strong cipher suites.
               - custom: Custom cipher suites.
        :param pulumi.Input[builtins.int] config_id: ConfigId of the configuration, which can be obtained by calling the [ListHttpsBasicConfigurations](https://www.alibabacloud.com/help/en/doc-detail/2867470.html) interface.
        :param pulumi.Input[builtins.str] http2: Indicates whether HTTP2 is enabled. Default is on. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] http3: Whether to enable HTTP3, which is enabled by default. The value can be:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] https: Whether to enable HTTPS. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] ocsp_stapling: Indicates whether OCSP is enabled. Default is off. Possible values:
               - on: Enabled.
               - off: Disabled.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               -  Match all incoming requests: value set to true
               -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        :param pulumi.Input[builtins.str] tls10: Whether to enable TLS1.0. Default is disabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls11: Whether to enable TLS1.1. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls12: Whether to enable TLS1.2. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        :param pulumi.Input[builtins.str] tls13: Whether to enable TLS1.3. Default is enabled. Possible values:
               - on: Enable.
               - off: Disable.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpsBasicConfigurationState.__new__(_HttpsBasicConfigurationState)

        __props__.__dict__["ciphersuite"] = ciphersuite
        __props__.__dict__["ciphersuite_group"] = ciphersuite_group
        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["http2"] = http2
        __props__.__dict__["http3"] = http3
        __props__.__dict__["https"] = https
        __props__.__dict__["ocsp_stapling"] = ocsp_stapling
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["tls10"] = tls10
        __props__.__dict__["tls11"] = tls11
        __props__.__dict__["tls12"] = tls12
        __props__.__dict__["tls13"] = tls13
        return HttpsBasicConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def ciphersuite(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Custom cipher suite, indicating the specific encryption algorithm selected when CiphersuiteGroup is set to custom.
        """
        return pulumi.get(self, "ciphersuite")

    @property
    @pulumi.getter(name="ciphersuiteGroup")
    def ciphersuite_group(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cipher suite group. Default is all cipher suites. Possible values:
        - all: All cipher suites.
        - strict: Strong cipher suites.
        - custom: Custom cipher suites.
        """
        return pulumi.get(self, "ciphersuite_group")

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        ConfigId of the configuration, which can be obtained by calling the [ListHttpsBasicConfigurations](https://www.alibabacloud.com/help/en/doc-detail/2867470.html) interface.
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter
    def http2(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Indicates whether HTTP2 is enabled. Default is on. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http2")

    @property
    @pulumi.getter
    def http3(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable HTTP3, which is enabled by default. The value can be:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "http3")

    @property
    @pulumi.getter
    def https(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable HTTPS. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "https")

    @property
    @pulumi.getter(name="ocspStapling")
    def ocsp_stapling(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Indicates whether OCSP is enabled. Default is off. Possible values:
        - on: Enabled.
        - off: Disabled.
        """
        return pulumi.get(self, "ocsp_stapling")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        -  Match all incoming requests: value set to true
        -  Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        Site ID, which can be obtained by calling the [ListSites](https://next.api.alibabacloud.com/document/ESA/2024-09-10/ListSites) interface.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def tls10(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable TLS1.0. Default is disabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls10")

    @property
    @pulumi.getter
    def tls11(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable TLS1.1. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls11")

    @property
    @pulumi.getter
    def tls12(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable TLS1.2. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls12")

    @property
    @pulumi.getter
    def tls13(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable TLS1.3. Default is enabled. Possible values:
        - on: Enable.
        - off: Disable.
        """
        return pulumi.get(self, "tls13")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceDatasetversionArgs', 'WorkspaceDatasetversion']

@pulumi.input_type
class WorkspaceDatasetversionArgs:
    def __init__(__self__, *,
                 data_source_type: pulumi.Input[builtins.str],
                 dataset_id: pulumi.Input[builtins.str],
                 property: pulumi.Input[builtins.str],
                 uri: pulumi.Input[builtins.str],
                 data_count: Optional[pulumi.Input[builtins.int]] = None,
                 data_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceDatasetversion resource.
        :param pulumi.Input[builtins.str] data_source_type: The data source type. The following values are supported:
               - OSS: Alibaba Cloud Object Storage (OSS).
               - NAS: Alibaba cloud file storage (NAS).
        :param pulumi.Input[builtins.str] dataset_id: The first ID of the resource
        :param pulumi.Input[builtins.str] property: The properties of the dataset. The following values are supported:
               - FILE: FILE.
               - DIRECTORY: folder.
        :param pulumi.Input[builtins.str] uri: The Uri configuration sample is as follows:
               - The data source type is OSS:'oss:// bucket.endpoint/object'
               - The data source type is NAS:
               
               The general NAS format is: 'nas://.region/subpath/to/dir/';
               
               CPFS1.0:'nas://.region/subpath/to/dir /';
               
               CPFS2.0:'nas://.region//'.
               
               CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        :param pulumi.Input[builtins.int] data_count: Data count.
        :param pulumi.Input[builtins.int] data_size: Data size.
        :param pulumi.Input[builtins.str] description: Description of dataset version.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]] labels: The tag of the resource See `labels` below.
        :param pulumi.Input[builtins.str] options: The extended field, which is of the JsonString type.
               
               When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        :param pulumi.Input[builtins.str] source_id: The data source ID.
        :param pulumi.Input[builtins.str] source_type: The data source type. The default value is USER.
        """
        pulumi.set(__self__, "data_source_type", data_source_type)
        pulumi.set(__self__, "dataset_id", dataset_id)
        pulumi.set(__self__, "property", property)
        pulumi.set(__self__, "uri", uri)
        if data_count is not None:
            pulumi.set(__self__, "data_count", data_count)
        if data_size is not None:
            pulumi.set(__self__, "data_size", data_size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if source_id is not None:
            pulumi.set(__self__, "source_id", source_id)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> pulumi.Input[builtins.str]:
        """
        The data source type. The following values are supported:
        - OSS: Alibaba Cloud Object Storage (OSS).
        - NAS: Alibaba cloud file storage (NAS).
        """
        return pulumi.get(self, "data_source_type")

    @data_source_type.setter
    def data_source_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "data_source_type", value)

    @property
    @pulumi.getter(name="datasetId")
    def dataset_id(self) -> pulumi.Input[builtins.str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "dataset_id")

    @dataset_id.setter
    def dataset_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "dataset_id", value)

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Input[builtins.str]:
        """
        The Uri configuration sample is as follows:
        - The data source type is OSS:'oss:// bucket.endpoint/object'
        - The data source type is NAS:

        The general NAS format is: 'nas://.region/subpath/to/dir/';

        CPFS1.0:'nas://.region/subpath/to/dir /';

        CPFS2.0:'nas://.region//'.

        CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="dataCount")
    def data_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Data count.
        """
        return pulumi.get(self, "data_count")

    @data_count.setter
    def data_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "data_count", value)

    @property
    @pulumi.getter(name="dataSize")
    def data_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Data size.
        """
        return pulumi.get(self, "data_size")

    @data_size.setter
    def data_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "data_size", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of dataset version.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]]:
        """
        The tag of the resource See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The extended field, which is of the JsonString type.

        When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source ID.
        """
        return pulumi.get(self, "source_id")

    @source_id.setter
    def source_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_id", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source type. The default value is USER.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def property(self) -> pulumi.Input[builtins.str]:
        """
        The properties of the dataset. The following values are supported:
        - FILE: FILE.
        - DIRECTORY: folder.
        """
        return pulumi.get(self, "property")

    @property.setter
    def property(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "property", value)


@pulumi.input_type
class _WorkspaceDatasetversionState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 data_count: Optional[pulumi.Input[builtins.int]] = None,
                 data_size: Optional[pulumi.Input[builtins.int]] = None,
                 data_source_type: Optional[pulumi.Input[builtins.str]] = None,
                 dataset_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 property: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 version_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceDatasetversion resources.
        :param pulumi.Input[builtins.str] create_time: Update time.
        :param pulumi.Input[builtins.int] data_count: Data count.
        :param pulumi.Input[builtins.int] data_size: Data size.
        :param pulumi.Input[builtins.str] data_source_type: The data source type. The following values are supported:
               - OSS: Alibaba Cloud Object Storage (OSS).
               - NAS: Alibaba cloud file storage (NAS).
        :param pulumi.Input[builtins.str] dataset_id: The first ID of the resource
        :param pulumi.Input[builtins.str] description: Description of dataset version.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]] labels: The tag of the resource See `labels` below.
        :param pulumi.Input[builtins.str] options: The extended field, which is of the JsonString type.
               
               When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        :param pulumi.Input[builtins.str] property: The properties of the dataset. The following values are supported:
               - FILE: FILE.
               - DIRECTORY: folder.
        :param pulumi.Input[builtins.str] source_id: The data source ID.
        :param pulumi.Input[builtins.str] source_type: The data source type. The default value is USER.
        :param pulumi.Input[builtins.str] uri: The Uri configuration sample is as follows:
               - The data source type is OSS:'oss:// bucket.endpoint/object'
               - The data source type is NAS:
               
               The general NAS format is: 'nas://.region/subpath/to/dir/';
               
               CPFS1.0:'nas://.region/subpath/to/dir /';
               
               CPFS2.0:'nas://.region//'.
               
               CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        :param pulumi.Input[builtins.str] version_name: The name of the resource
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data_count is not None:
            pulumi.set(__self__, "data_count", data_count)
        if data_size is not None:
            pulumi.set(__self__, "data_size", data_size)
        if data_source_type is not None:
            pulumi.set(__self__, "data_source_type", data_source_type)
        if dataset_id is not None:
            pulumi.set(__self__, "dataset_id", dataset_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if property is not None:
            pulumi.set(__self__, "property", property)
        if source_id is not None:
            pulumi.set(__self__, "source_id", source_id)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if version_name is not None:
            pulumi.set(__self__, "version_name", version_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Update time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dataCount")
    def data_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Data count.
        """
        return pulumi.get(self, "data_count")

    @data_count.setter
    def data_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "data_count", value)

    @property
    @pulumi.getter(name="dataSize")
    def data_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Data size.
        """
        return pulumi.get(self, "data_size")

    @data_size.setter
    def data_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "data_size", value)

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source type. The following values are supported:
        - OSS: Alibaba Cloud Object Storage (OSS).
        - NAS: Alibaba cloud file storage (NAS).
        """
        return pulumi.get(self, "data_source_type")

    @data_source_type.setter
    def data_source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_source_type", value)

    @property
    @pulumi.getter(name="datasetId")
    def dataset_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "dataset_id")

    @dataset_id.setter
    def dataset_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dataset_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of dataset version.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]]:
        """
        The tag of the resource See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceDatasetversionLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The extended field, which is of the JsonString type.

        When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source ID.
        """
        return pulumi.get(self, "source_id")

    @source_id.setter
    def source_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_id", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data source type. The default value is USER.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Uri configuration sample is as follows:
        - The data source type is OSS:'oss:// bucket.endpoint/object'
        - The data source type is NAS:

        The general NAS format is: 'nas://.region/subpath/to/dir/';

        CPFS1.0:'nas://.region/subpath/to/dir /';

        CPFS2.0:'nas://.region//'.

        CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "version_name")

    @version_name.setter
    def version_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_name", value)

    @property
    @pulumi.getter
    def property(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The properties of the dataset. The following values are supported:
        - FILE: FILE.
        - DIRECTORY: folder.
        """
        return pulumi.get(self, "property")

    @property.setter
    def property(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "property", value)


@pulumi.type_token("alicloud:pai/workspaceDatasetversion:WorkspaceDatasetversion")
class WorkspaceDatasetversion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_count: Optional[pulumi.Input[builtins.int]] = None,
                 data_size: Optional[pulumi.Input[builtins.int]] = None,
                 data_source_type: Optional[pulumi.Input[builtins.str]] = None,
                 dataset_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceDatasetversionLabelArgs', 'WorkspaceDatasetversionLabelArgsDict']]]]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 property: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a PAI Workspace Datasetversion resource.

        For information about PAI Workspace Dataset Version and how to use it, see [What is Dataset Version](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateDatasetVersion).
        > **NOTE:** Available since v1.236.0.

        ## Import

        PAI Workspace Datasetversion can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceDatasetversion:WorkspaceDatasetversion example <dataset_id>:<version_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] data_count: Data count.
        :param pulumi.Input[builtins.int] data_size: Data size.
        :param pulumi.Input[builtins.str] data_source_type: The data source type. The following values are supported:
               - OSS: Alibaba Cloud Object Storage (OSS).
               - NAS: Alibaba cloud file storage (NAS).
        :param pulumi.Input[builtins.str] dataset_id: The first ID of the resource
        :param pulumi.Input[builtins.str] description: Description of dataset version.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceDatasetversionLabelArgs', 'WorkspaceDatasetversionLabelArgsDict']]]] labels: The tag of the resource See `labels` below.
        :param pulumi.Input[builtins.str] options: The extended field, which is of the JsonString type.
               
               When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        :param pulumi.Input[builtins.str] property: The properties of the dataset. The following values are supported:
               - FILE: FILE.
               - DIRECTORY: folder.
        :param pulumi.Input[builtins.str] source_id: The data source ID.
        :param pulumi.Input[builtins.str] source_type: The data source type. The default value is USER.
        :param pulumi.Input[builtins.str] uri: The Uri configuration sample is as follows:
               - The data source type is OSS:'oss:// bucket.endpoint/object'
               - The data source type is NAS:
               
               The general NAS format is: 'nas://.region/subpath/to/dir/';
               
               CPFS1.0:'nas://.region/subpath/to/dir /';
               
               CPFS2.0:'nas://.region//'.
               
               CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceDatasetversionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a PAI Workspace Datasetversion resource.

        For information about PAI Workspace Dataset Version and how to use it, see [What is Dataset Version](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateDatasetVersion).
        > **NOTE:** Available since v1.236.0.

        ## Import

        PAI Workspace Datasetversion can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceDatasetversion:WorkspaceDatasetversion example <dataset_id>:<version_name>
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceDatasetversionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceDatasetversionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_count: Optional[pulumi.Input[builtins.int]] = None,
                 data_size: Optional[pulumi.Input[builtins.int]] = None,
                 data_source_type: Optional[pulumi.Input[builtins.str]] = None,
                 dataset_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceDatasetversionLabelArgs', 'WorkspaceDatasetversionLabelArgsDict']]]]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 property: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceDatasetversionArgs.__new__(WorkspaceDatasetversionArgs)

            __props__.__dict__["data_count"] = data_count
            __props__.__dict__["data_size"] = data_size
            if data_source_type is None and not opts.urn:
                raise TypeError("Missing required property 'data_source_type'")
            __props__.__dict__["data_source_type"] = data_source_type
            if dataset_id is None and not opts.urn:
                raise TypeError("Missing required property 'dataset_id'")
            __props__.__dict__["dataset_id"] = dataset_id
            __props__.__dict__["description"] = description
            __props__.__dict__["labels"] = labels
            __props__.__dict__["options"] = options
            if property is None and not opts.urn:
                raise TypeError("Missing required property 'property'")
            __props__.__dict__["property"] = property
            __props__.__dict__["source_id"] = source_id
            __props__.__dict__["source_type"] = source_type
            if uri is None and not opts.urn:
                raise TypeError("Missing required property 'uri'")
            __props__.__dict__["uri"] = uri
            __props__.__dict__["create_time"] = None
            __props__.__dict__["version_name"] = None
        super(WorkspaceDatasetversion, __self__).__init__(
            'alicloud:pai/workspaceDatasetversion:WorkspaceDatasetversion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            data_count: Optional[pulumi.Input[builtins.int]] = None,
            data_size: Optional[pulumi.Input[builtins.int]] = None,
            data_source_type: Optional[pulumi.Input[builtins.str]] = None,
            dataset_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceDatasetversionLabelArgs', 'WorkspaceDatasetversionLabelArgsDict']]]]] = None,
            options: Optional[pulumi.Input[builtins.str]] = None,
            property: Optional[pulumi.Input[builtins.str]] = None,
            source_id: Optional[pulumi.Input[builtins.str]] = None,
            source_type: Optional[pulumi.Input[builtins.str]] = None,
            uri: Optional[pulumi.Input[builtins.str]] = None,
            version_name: Optional[pulumi.Input[builtins.str]] = None) -> 'WorkspaceDatasetversion':
        """
        Get an existing WorkspaceDatasetversion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: Update time.
        :param pulumi.Input[builtins.int] data_count: Data count.
        :param pulumi.Input[builtins.int] data_size: Data size.
        :param pulumi.Input[builtins.str] data_source_type: The data source type. The following values are supported:
               - OSS: Alibaba Cloud Object Storage (OSS).
               - NAS: Alibaba cloud file storage (NAS).
        :param pulumi.Input[builtins.str] dataset_id: The first ID of the resource
        :param pulumi.Input[builtins.str] description: Description of dataset version.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceDatasetversionLabelArgs', 'WorkspaceDatasetversionLabelArgsDict']]]] labels: The tag of the resource See `labels` below.
        :param pulumi.Input[builtins.str] options: The extended field, which is of the JsonString type.
               
               When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        :param pulumi.Input[builtins.str] property: The properties of the dataset. The following values are supported:
               - FILE: FILE.
               - DIRECTORY: folder.
        :param pulumi.Input[builtins.str] source_id: The data source ID.
        :param pulumi.Input[builtins.str] source_type: The data source type. The default value is USER.
        :param pulumi.Input[builtins.str] uri: The Uri configuration sample is as follows:
               - The data source type is OSS:'oss:// bucket.endpoint/object'
               - The data source type is NAS:
               
               The general NAS format is: 'nas://.region/subpath/to/dir/';
               
               CPFS1.0:'nas://.region/subpath/to/dir /';
               
               CPFS2.0:'nas://.region//'.
               
               CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        :param pulumi.Input[builtins.str] version_name: The name of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceDatasetversionState.__new__(_WorkspaceDatasetversionState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data_count"] = data_count
        __props__.__dict__["data_size"] = data_size
        __props__.__dict__["data_source_type"] = data_source_type
        __props__.__dict__["dataset_id"] = dataset_id
        __props__.__dict__["description"] = description
        __props__.__dict__["labels"] = labels
        __props__.__dict__["options"] = options
        __props__.__dict__["property"] = property
        __props__.__dict__["source_id"] = source_id
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["uri"] = uri
        __props__.__dict__["version_name"] = version_name
        return WorkspaceDatasetversion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Update time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataCount")
    def data_count(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Data count.
        """
        return pulumi.get(self, "data_count")

    @property
    @pulumi.getter(name="dataSize")
    def data_size(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Data size.
        """
        return pulumi.get(self, "data_size")

    @property
    @pulumi.getter(name="dataSourceType")
    def data_source_type(self) -> pulumi.Output[builtins.str]:
        """
        The data source type. The following values are supported:
        - OSS: Alibaba Cloud Object Storage (OSS).
        - NAS: Alibaba cloud file storage (NAS).
        """
        return pulumi.get(self, "data_source_type")

    @property
    @pulumi.getter(name="datasetId")
    def dataset_id(self) -> pulumi.Output[builtins.str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "dataset_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of dataset version.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceDatasetversionLabel']]]:
        """
        The tag of the resource See `labels` below.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The extended field, which is of the JsonString type.

        When DLC uses a dataset, you can specify the default Mount path for the dataset by configuring the mountPath field.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The data source ID.
        """
        return pulumi.get(self, "source_id")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The data source type. The default value is USER.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Output[builtins.str]:
        """
        The Uri configuration sample is as follows:
        - The data source type is OSS:'oss:// bucket.endpoint/object'
        - The data source type is NAS:

        The general NAS format is: 'nas://.region/subpath/to/dir/';

        CPFS1.0:'nas://.region/subpath/to/dir /';

        CPFS2.0:'nas://.region//'.

        CPFS1.0 and CPFS2.0 are distinguished by the format of fsid: CPFS1.0 is cpfs-;CPFS2.0 is cpfs-.
        """
        return pulumi.get(self, "uri")

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the resource
        """
        return pulumi.get(self, "version_name")

    @property
    @pulumi.getter
    def property(self) -> pulumi.Output[builtins.str]:
        """
        The properties of the dataset. The following values are supported:
        - FILE: FILE.
        - DIRECTORY: folder.
        """
        return pulumi.get(self, "property")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ScheduledPreloadJobArgs', 'ScheduledPreloadJob']

@pulumi.input_type
class ScheduledPreloadJobArgs:
    def __init__(__self__, *,
                 insert_way: pulumi.Input[builtins.str],
                 scheduled_preload_job_name: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 oss_url: Optional[pulumi.Input[builtins.str]] = None,
                 url_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ScheduledPreloadJob resource.
        :param pulumi.Input[builtins.str] insert_way: The method to submit the URLs to be prefetched.
        :param pulumi.Input[builtins.str] scheduled_preload_job_name: The task name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] oss_url: Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        :param pulumi.Input[builtins.str] url_list: A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        pulumi.set(__self__, "insert_way", insert_way)
        pulumi.set(__self__, "scheduled_preload_job_name", scheduled_preload_job_name)
        pulumi.set(__self__, "site_id", site_id)
        if oss_url is not None:
            pulumi.set(__self__, "oss_url", oss_url)
        if url_list is not None:
            pulumi.set(__self__, "url_list", url_list)

    @property
    @pulumi.getter(name="insertWay")
    def insert_way(self) -> pulumi.Input[builtins.str]:
        """
        The method to submit the URLs to be prefetched.
        """
        return pulumi.get(self, "insert_way")

    @insert_way.setter
    def insert_way(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "insert_way", value)

    @property
    @pulumi.getter(name="scheduledPreloadJobName")
    def scheduled_preload_job_name(self) -> pulumi.Input[builtins.str]:
        """
        The task name.
        """
        return pulumi.get(self, "scheduled_preload_job_name")

    @scheduled_preload_job_name.setter
    def scheduled_preload_job_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "scheduled_preload_job_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="ossUrl")
    def oss_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        """
        return pulumi.get(self, "oss_url")

    @oss_url.setter
    def oss_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oss_url", value)

    @property
    @pulumi.getter(name="urlList")
    def url_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        return pulumi.get(self, "url_list")

    @url_list.setter
    def url_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url_list", value)


@pulumi.input_type
class _ScheduledPreloadJobState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 insert_way: Optional[pulumi.Input[builtins.str]] = None,
                 oss_url: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_preload_job_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 url_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ScheduledPreloadJob resources.
        :param pulumi.Input[builtins.str] create_time: The time when the task was created.
        :param pulumi.Input[builtins.str] insert_way: The method to submit the URLs to be prefetched.
        :param pulumi.Input[builtins.str] oss_url: Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.str] scheduled_preload_job_name: The task name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] url_list: A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if insert_way is not None:
            pulumi.set(__self__, "insert_way", insert_way)
        if oss_url is not None:
            pulumi.set(__self__, "oss_url", oss_url)
        if scheduled_preload_job_id is not None:
            pulumi.set(__self__, "scheduled_preload_job_id", scheduled_preload_job_id)
        if scheduled_preload_job_name is not None:
            pulumi.set(__self__, "scheduled_preload_job_name", scheduled_preload_job_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if url_list is not None:
            pulumi.set(__self__, "url_list", url_list)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the task was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="insertWay")
    def insert_way(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The method to submit the URLs to be prefetched.
        """
        return pulumi.get(self, "insert_way")

    @insert_way.setter
    def insert_way(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "insert_way", value)

    @property
    @pulumi.getter(name="ossUrl")
    def oss_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        """
        return pulumi.get(self, "oss_url")

    @oss_url.setter
    def oss_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oss_url", value)

    @property
    @pulumi.getter(name="scheduledPreloadJobId")
    def scheduled_preload_job_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the prefetch task.
        """
        return pulumi.get(self, "scheduled_preload_job_id")

    @scheduled_preload_job_id.setter
    def scheduled_preload_job_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduled_preload_job_id", value)

    @property
    @pulumi.getter(name="scheduledPreloadJobName")
    def scheduled_preload_job_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The task name.
        """
        return pulumi.get(self, "scheduled_preload_job_name")

    @scheduled_preload_job_name.setter
    def scheduled_preload_job_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduled_preload_job_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="urlList")
    def url_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        return pulumi.get(self, "url_list")

    @url_list.setter
    def url_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url_list", value)


@pulumi.type_token("alicloud:esa/scheduledPreloadJob:ScheduledPreloadJob")
class ScheduledPreloadJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 insert_way: Optional[pulumi.Input[builtins.str]] = None,
                 oss_url: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_preload_job_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 url_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Scheduled Preload Job resource.

        For information about ESA Scheduled Preload Job and how to use it, see [What is Scheduled Preload Job](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateScheduledPreloadJob).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_scheduled_preload_job = alicloud.esa.ScheduledPreloadJob("default",
            insert_way="textBox",
            site_id=default_site.id,
            scheduled_preload_job_name="example_scheduledpreloadexecution_job",
            url_list="http://example.gositecdn.cn/example/example.txt")
        ```

        ## Import

        ESA Scheduled Preload Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/scheduledPreloadJob:ScheduledPreloadJob example <site_id>:<scheduled_preload_job_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] insert_way: The method to submit the URLs to be prefetched.
        :param pulumi.Input[builtins.str] oss_url: Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        :param pulumi.Input[builtins.str] scheduled_preload_job_name: The task name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] url_list: A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScheduledPreloadJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Scheduled Preload Job resource.

        For information about ESA Scheduled Preload Job and how to use it, see [What is Scheduled Preload Job](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateScheduledPreloadJob).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="terraform.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_scheduled_preload_job = alicloud.esa.ScheduledPreloadJob("default",
            insert_way="textBox",
            site_id=default_site.id,
            scheduled_preload_job_name="example_scheduledpreloadexecution_job",
            url_list="http://example.gositecdn.cn/example/example.txt")
        ```

        ## Import

        ESA Scheduled Preload Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/scheduledPreloadJob:ScheduledPreloadJob example <site_id>:<scheduled_preload_job_id>
        ```

        :param str resource_name: The name of the resource.
        :param ScheduledPreloadJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScheduledPreloadJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 insert_way: Optional[pulumi.Input[builtins.str]] = None,
                 oss_url: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_preload_job_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 url_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScheduledPreloadJobArgs.__new__(ScheduledPreloadJobArgs)

            if insert_way is None and not opts.urn:
                raise TypeError("Missing required property 'insert_way'")
            __props__.__dict__["insert_way"] = insert_way
            __props__.__dict__["oss_url"] = oss_url
            if scheduled_preload_job_name is None and not opts.urn:
                raise TypeError("Missing required property 'scheduled_preload_job_name'")
            __props__.__dict__["scheduled_preload_job_name"] = scheduled_preload_job_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["url_list"] = url_list
            __props__.__dict__["create_time"] = None
            __props__.__dict__["scheduled_preload_job_id"] = None
        super(ScheduledPreloadJob, __self__).__init__(
            'alicloud:esa/scheduledPreloadJob:ScheduledPreloadJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            insert_way: Optional[pulumi.Input[builtins.str]] = None,
            oss_url: Optional[pulumi.Input[builtins.str]] = None,
            scheduled_preload_job_id: Optional[pulumi.Input[builtins.str]] = None,
            scheduled_preload_job_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            url_list: Optional[pulumi.Input[builtins.str]] = None) -> 'ScheduledPreloadJob':
        """
        Get an existing ScheduledPreloadJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The time when the task was created.
        :param pulumi.Input[builtins.str] insert_way: The method to submit the URLs to be prefetched.
        :param pulumi.Input[builtins.str] oss_url: Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        :param pulumi.Input[builtins.str] scheduled_preload_job_id: The ID of the prefetch task.
        :param pulumi.Input[builtins.str] scheduled_preload_job_name: The task name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] url_list: A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScheduledPreloadJobState.__new__(_ScheduledPreloadJobState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["insert_way"] = insert_way
        __props__.__dict__["oss_url"] = oss_url
        __props__.__dict__["scheduled_preload_job_id"] = scheduled_preload_job_id
        __props__.__dict__["scheduled_preload_job_name"] = scheduled_preload_job_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["url_list"] = url_list
        return ScheduledPreloadJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the task was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="insertWay")
    def insert_way(self) -> pulumi.Output[builtins.str]:
        """
        The method to submit the URLs to be prefetched.
        """
        return pulumi.get(self, "insert_way")

    @property
    @pulumi.getter(name="ossUrl")
    def oss_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Preheat OSS files regularly and fill in the OSS file address. Note: The OSS file contains the URL that you need to warm up.
        """
        return pulumi.get(self, "oss_url")

    @property
    @pulumi.getter(name="scheduledPreloadJobId")
    def scheduled_preload_job_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the prefetch task.
        """
        return pulumi.get(self, "scheduled_preload_job_id")

    @property
    @pulumi.getter(name="scheduledPreloadJobName")
    def scheduled_preload_job_name(self) -> pulumi.Output[builtins.str]:
        """
        The task name.
        """
        return pulumi.get(self, "scheduled_preload_job_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="urlList")
    def url_list(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A list of URLs to be preheated, which is used when uploading a preheated file in the text box mode.
        """
        return pulumi.get(self, "url_list")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['WorkspaceExperimentArgs', 'WorkspaceExperiment']

@pulumi.input_type
class WorkspaceExperimentArgs:
    def __init__(__self__, *,
                 artifact_uri: pulumi.Input[builtins.str],
                 experiment_name: pulumi.Input[builtins.str],
                 workspace_id: pulumi.Input[builtins.str],
                 accessibility: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceExperiment resource.
        :param pulumi.Input[builtins.str] artifact_uri: ArtifactUri is default OSS storage path of the output of trials in the experiment
        :param pulumi.Input[builtins.str] experiment_name: Name is the name of the experiment, unique in a namespace
        :param pulumi.Input[builtins.str] workspace_id: WorkspaceId is the workspace id which contains the experiment
        :param pulumi.Input[builtins.str] accessibility: Experimental Visibility
        """
        pulumi.set(__self__, "artifact_uri", artifact_uri)
        pulumi.set(__self__, "experiment_name", experiment_name)
        pulumi.set(__self__, "workspace_id", workspace_id)
        if accessibility is not None:
            pulumi.set(__self__, "accessibility", accessibility)

    @property
    @pulumi.getter(name="artifactUri")
    def artifact_uri(self) -> pulumi.Input[builtins.str]:
        """
        ArtifactUri is default OSS storage path of the output of trials in the experiment
        """
        return pulumi.get(self, "artifact_uri")

    @artifact_uri.setter
    def artifact_uri(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "artifact_uri", value)

    @property
    @pulumi.getter(name="experimentName")
    def experiment_name(self) -> pulumi.Input[builtins.str]:
        """
        Name is the name of the experiment, unique in a namespace
        """
        return pulumi.get(self, "experiment_name")

    @experiment_name.setter
    def experiment_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "experiment_name", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Input[builtins.str]:
        """
        WorkspaceId is the workspace id which contains the experiment
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "workspace_id", value)

    @property
    @pulumi.getter
    def accessibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Experimental Visibility
        """
        return pulumi.get(self, "accessibility")

    @accessibility.setter
    def accessibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility", value)


@pulumi.input_type
class _WorkspaceExperimentState:
    def __init__(__self__, *,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 artifact_uri: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 experiment_name: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceExperiment resources.
        :param pulumi.Input[builtins.str] accessibility: Experimental Visibility
        :param pulumi.Input[builtins.str] artifact_uri: ArtifactUri is default OSS storage path of the output of trials in the experiment
        :param pulumi.Input[builtins.str] create_time: GmtCreateTime is time when this entity is created.
        :param pulumi.Input[builtins.str] experiment_name: Name is the name of the experiment, unique in a namespace
        :param pulumi.Input[builtins.str] workspace_id: WorkspaceId is the workspace id which contains the experiment
        """
        if accessibility is not None:
            pulumi.set(__self__, "accessibility", accessibility)
        if artifact_uri is not None:
            pulumi.set(__self__, "artifact_uri", artifact_uri)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if experiment_name is not None:
            pulumi.set(__self__, "experiment_name", experiment_name)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter
    def accessibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Experimental Visibility
        """
        return pulumi.get(self, "accessibility")

    @accessibility.setter
    def accessibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility", value)

    @property
    @pulumi.getter(name="artifactUri")
    def artifact_uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ArtifactUri is default OSS storage path of the output of trials in the experiment
        """
        return pulumi.get(self, "artifact_uri")

    @artifact_uri.setter
    def artifact_uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "artifact_uri", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        GmtCreateTime is time when this entity is created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="experimentName")
    def experiment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name is the name of the experiment, unique in a namespace
        """
        return pulumi.get(self, "experiment_name")

    @experiment_name.setter
    def experiment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "experiment_name", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        WorkspaceId is the workspace id which contains the experiment
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("alicloud:pai/workspaceExperiment:WorkspaceExperiment")
class WorkspaceExperiment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 artifact_uri: Optional[pulumi.Input[builtins.str]] = None,
                 experiment_name: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a PAI Workspace Experiment resource.

        For information about PAI Workspace Experiment and how to use it, see [What is Experiment](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateExperiment).

        > **NOTE:** Available since v1.236.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default_di9fs_l = alicloud.pai.WorkspaceWorkspace("defaultDI9fsL",
            description=name,
            display_name=name,
            workspace_name=name,
            env_types=["prod"])
        default = alicloud.pai.WorkspaceExperiment("default",
            accessibility="PRIVATE",
            artifact_uri="oss://yyt-409262.oss-cn-hangzhou.aliyuncs.com/example/",
            experiment_name=name,
            workspace_id=default_di9fs_l.id)
        ```

        ## Import

        PAI Workspace Experiment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceExperiment:WorkspaceExperiment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility: Experimental Visibility
        :param pulumi.Input[builtins.str] artifact_uri: ArtifactUri is default OSS storage path of the output of trials in the experiment
        :param pulumi.Input[builtins.str] experiment_name: Name is the name of the experiment, unique in a namespace
        :param pulumi.Input[builtins.str] workspace_id: WorkspaceId is the workspace id which contains the experiment
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceExperimentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a PAI Workspace Experiment resource.

        For information about PAI Workspace Experiment and how to use it, see [What is Experiment](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateExperiment).

        > **NOTE:** Available since v1.236.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default_di9fs_l = alicloud.pai.WorkspaceWorkspace("defaultDI9fsL",
            description=name,
            display_name=name,
            workspace_name=name,
            env_types=["prod"])
        default = alicloud.pai.WorkspaceExperiment("default",
            accessibility="PRIVATE",
            artifact_uri="oss://yyt-409262.oss-cn-hangzhou.aliyuncs.com/example/",
            experiment_name=name,
            workspace_id=default_di9fs_l.id)
        ```

        ## Import

        PAI Workspace Experiment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceExperiment:WorkspaceExperiment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceExperimentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceExperimentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 artifact_uri: Optional[pulumi.Input[builtins.str]] = None,
                 experiment_name: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceExperimentArgs.__new__(WorkspaceExperimentArgs)

            __props__.__dict__["accessibility"] = accessibility
            if artifact_uri is None and not opts.urn:
                raise TypeError("Missing required property 'artifact_uri'")
            __props__.__dict__["artifact_uri"] = artifact_uri
            if experiment_name is None and not opts.urn:
                raise TypeError("Missing required property 'experiment_name'")
            __props__.__dict__["experiment_name"] = experiment_name
            if workspace_id is None and not opts.urn:
                raise TypeError("Missing required property 'workspace_id'")
            __props__.__dict__["workspace_id"] = workspace_id
            __props__.__dict__["create_time"] = None
        super(WorkspaceExperiment, __self__).__init__(
            'alicloud:pai/workspaceExperiment:WorkspaceExperiment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessibility: Optional[pulumi.Input[builtins.str]] = None,
            artifact_uri: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            experiment_name: Optional[pulumi.Input[builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[builtins.str]] = None) -> 'WorkspaceExperiment':
        """
        Get an existing WorkspaceExperiment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility: Experimental Visibility
        :param pulumi.Input[builtins.str] artifact_uri: ArtifactUri is default OSS storage path of the output of trials in the experiment
        :param pulumi.Input[builtins.str] create_time: GmtCreateTime is time when this entity is created.
        :param pulumi.Input[builtins.str] experiment_name: Name is the name of the experiment, unique in a namespace
        :param pulumi.Input[builtins.str] workspace_id: WorkspaceId is the workspace id which contains the experiment
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceExperimentState.__new__(_WorkspaceExperimentState)

        __props__.__dict__["accessibility"] = accessibility
        __props__.__dict__["artifact_uri"] = artifact_uri
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["experiment_name"] = experiment_name
        __props__.__dict__["workspace_id"] = workspace_id
        return WorkspaceExperiment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def accessibility(self) -> pulumi.Output[builtins.str]:
        """
        Experimental Visibility
        """
        return pulumi.get(self, "accessibility")

    @property
    @pulumi.getter(name="artifactUri")
    def artifact_uri(self) -> pulumi.Output[builtins.str]:
        """
        ArtifactUri is default OSS storage path of the output of trials in the experiment
        """
        return pulumi.get(self, "artifact_uri")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        GmtCreateTime is time when this entity is created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="experimentName")
    def experiment_name(self) -> pulumi.Output[builtins.str]:
        """
        Name is the name of the experiment, unique in a namespace
        """
        return pulumi.get(self, "experiment_name")

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[builtins.str]:
        """
        WorkspaceId is the workspace id which contains the experiment
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['MembershipAttachmentArgs', 'MembershipAttachment']

@pulumi.input_type
class MembershipAttachmentArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 sub_cluster_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a MembershipAttachment resource.
        :param pulumi.Input[builtins.str] cluster_id: The ID of the cluster to which the membership is being attached.
        :param pulumi.Input[builtins.str] sub_cluster_id: The ID of the member being attached to the cluster.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "sub_cluster_id", sub_cluster_id)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the cluster to which the membership is being attached.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="subClusterId")
    def sub_cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the member being attached to the cluster.
        """
        return pulumi.get(self, "sub_cluster_id")

    @sub_cluster_id.setter
    def sub_cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "sub_cluster_id", value)


@pulumi.input_type
class _MembershipAttachmentState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 sub_cluster_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering MembershipAttachment resources.
        :param pulumi.Input[builtins.str] cluster_id: The ID of the cluster to which the membership is being attached.
        :param pulumi.Input[builtins.str] sub_cluster_id: The ID of the member being attached to the cluster.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if sub_cluster_id is not None:
            pulumi.set(__self__, "sub_cluster_id", sub_cluster_id)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the cluster to which the membership is being attached.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="subClusterId")
    def sub_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the member being attached to the cluster.
        """
        return pulumi.get(self, "sub_cluster_id")

    @sub_cluster_id.setter
    def sub_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sub_cluster_id", value)


@pulumi.type_token("alicloud:ackone/membershipAttachment:MembershipAttachment")
class MembershipAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 sub_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides an Ack One Membership Attachment resource. Fleet Manager Membership Attachment.

        For information about Ack One Membership Attachment and how to use it, see [How to attach cluster tp hub](https://www.alibabacloud.com/help/en/ack/distributed-cloud-container-platform-for-kubernetes/developer-reference/api-adcp-2022-01-01-attachclustertohub).

        > **NOTE:** Available since v1.243.0.

        ## Import

        Ack One Membership Attachment can be imported using the id, which consists of cluster_id and sub_cluster_id, e.g.

        ```sh
        $ pulumi import alicloud:ackone/membershipAttachment:MembershipAttachment example <cluster_id>:<sub_cluster_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: The ID of the cluster to which the membership is being attached.
        :param pulumi.Input[builtins.str] sub_cluster_id: The ID of the member being attached to the cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MembershipAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an Ack One Membership Attachment resource. Fleet Manager Membership Attachment.

        For information about Ack One Membership Attachment and how to use it, see [How to attach cluster tp hub](https://www.alibabacloud.com/help/en/ack/distributed-cloud-container-platform-for-kubernetes/developer-reference/api-adcp-2022-01-01-attachclustertohub).

        > **NOTE:** Available since v1.243.0.

        ## Import

        Ack One Membership Attachment can be imported using the id, which consists of cluster_id and sub_cluster_id, e.g.

        ```sh
        $ pulumi import alicloud:ackone/membershipAttachment:MembershipAttachment example <cluster_id>:<sub_cluster_id>
        ```

        :param str resource_name: The name of the resource.
        :param MembershipAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MembershipAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 sub_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MembershipAttachmentArgs.__new__(MembershipAttachmentArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if sub_cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'sub_cluster_id'")
            __props__.__dict__["sub_cluster_id"] = sub_cluster_id
        super(MembershipAttachment, __self__).__init__(
            'alicloud:ackone/membershipAttachment:MembershipAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            sub_cluster_id: Optional[pulumi.Input[builtins.str]] = None) -> 'MembershipAttachment':
        """
        Get an existing MembershipAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: The ID of the cluster to which the membership is being attached.
        :param pulumi.Input[builtins.str] sub_cluster_id: The ID of the member being attached to the cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MembershipAttachmentState.__new__(_MembershipAttachmentState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["sub_cluster_id"] = sub_cluster_id
        return MembershipAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the cluster to which the membership is being attached.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="subClusterId")
    def sub_cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the member being attached to the cluster.
        """
        return pulumi.get(self, "sub_cluster_id")

